#
# See the file "LICENSE" for the full license governing this code.
#
#
# Function to fetch the fact ora_is_root_db and based on that information
# decide if the specfied sid is a root database or not.
#
Puppet::Functions.create_function('ora_config::is_root_db') do
    dispatch :is_root_db do
      param       'String', :sid
      # return_type 'Boolean' TODO: Wait until the Puppet version supporting this, is mainstream
    end

    def is_root_db(sid)
      variable = 'ora_is_root_db'
      if variable_exists?(variable)
        fact_value = closure_scope.lookupvar("::#{variable}")
        fact_value ? call_function('ora_config::on_sid', fact_value, sid) == ['TRUE'] : false
      else
        #
        # This is probably oracle 11. So assume it is not a root db
        #
        false
      end
    end

    # Check if the variable exists without generating a warning
    def variable_exists?(var)
      closure_scope.to_hash.keys.include?(var)
    end
  end
