#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/access'
require 'easy_type'

Puppet::Type.type(:ora_object_grant).provide(:prefetching) do
  include EasyType::Provider
  include EasyType::Helpers
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Information
  include EasyType::Template

  confine :exists => settings_file

  desc 'Manage Oracle object permissions via regular SQL'

  mk_resource_methods

  def self.all_resources
    where_clause = false
    statement = for_version(
      :'12'     => template('ora_config/ora_object_grant/index_v12.sql.erb', binding),
      :'18'     => template('ora_config/ora_object_grant/index_v12.sql.erb', binding),
      :default  => template('ora_config/ora_object_grant/index.sql.erb', binding)
    )
    sql_on_all_primary_database_sids(statement)
  end

  def self.instances_for(resources)
    non_wildcard_resources = filter_wildcard_resources(resources)
    return [] if non_wildcard_resources.empty?
    grantees      = non_wildcard_resources.collect { |k| resources[k].grantee }.uniq
    object_names  = non_wildcard_resources.collect { |k| resources[k].object_name }.uniq
    owners        = object_names.map{ |o| o.split('.').first}.uniq
    table_names   = object_names.map{ |o| o.split('.').last}.uniq
    where_clause  = true
    statement = for_version(
      :'12'     => template('ora_config/ora_object_grant/index_v12.sql.erb', binding),
      :'18'     => template('ora_config/ora_object_grant/index_v12.sql.erb', binding),
      :default  => template('ora_config/ora_object_grant/index.sql.erb', binding)
    )
    raw_resources = sql_on_all_primary_database_sids(statement)
    raw_resources.map do |raw_resource|
      map_raw_to_resource(raw_resource)
    end
  end

  def self.prefetch(resources)
    objects = instances_for(resources)
    resources.each_key do |name|
      provider = objects.find { |object| object.name == name }
      resources[name].provider = provider if provider
    end
  end

  def self.filter_wildcard_resources(resources)
    resources.keys.reject do | title |
      owner, table_name = resources[title].object_name.split('.')
      table_name.include?('%')
    end
  end
end
