#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/commands'
require 'easy_type'

Puppet::Type.type(:ora_service).provide(:oracle11) do
  include EasyType::Provider
  include Puppet_X::EnterpriseModules::Oracle::Commands
  include Puppet_X::EnterpriseModules::Oracle::Settings

  confine :exists => settings_file
  confine :feature => :oracle_running
  confine :feature => :oracle11

  desc 'Manage Oracle services using srvctl syntax for Oracle 11 provider.'

  mk_resource_methods

  # aq_ha_notifications
  def apply_aq_ha_notifications(value)
    "-q #{value}"
  end

  # available_instances
  def create_available_instances(value)
    "-a '#{value.join(',')}'"
  end

  def update_available_instances(value)
    "-n -a '#{value.join(',')}'"
  end

  # clb_goal
  def apply_clb_goal(value)
    "-j #{value}"
  end

  # commit_outcome
  def apply_commit_outcome(value)
    # Not applicable in Oracle 11g
  end

  # drain_timeout
  def apply_drain_timeout(value)
    # Not applicable in Oracle 11g
  end

  # dtp
  def apply_dtp(value)
    "-x #{value}"
  end

  # failover_delay
  def apply_failover_delay(value)
    "-w #{value}"
  end

  # failover_method
  def apply_failover_method(value)
    "-m #{value}"
  end

  # failover_restore
  def apply_failover_restore(value)
    # Not applicable in Oracle 11g
  end

  # failover_retries
  def apply_failover_retries(value)
    "-z #{value}"
  end

  # failover_type
  def apply_failover_type(value)
    "-e #{value}"
  end

  # lb_advisory
  def apply_lb_advisory(value)
    "-B #{value}"
  end

  # management_policy
  def apply_management_policy(value)
    "-y #{value}"
  end

  # network_number
  def apply_network_number(value)
    "-k #{value}"
  end

  # preferred_instances
  def create_preferred_instances(value)
    "-r '#{value.join(',')}'"
  end

  def update_preferred_instances(value)
    "-n -i '#{value.join(',')}'"
  end

  # replay_init_time
  def apply_replay_init_time(value)
    # Not applicable in Oracle 11g
  end

  # retention
  def apply_retention(value)
    # Not applicable in Oracle 11g
  end

  # server_pool
  def apply_server_pool(value)
    "-g '#{value.join(',')}'"
  end

  # service_role
  def apply_service_role(value)
    "-l #{value}"
  end

  # session_state
  def apply_session_state(value)
    # Not applicable in Oracle 11g
  end

  # stopoption
  def apply_stopoption(value)
    # Not applicable in Oracle 11g
  end

  # taf_policy
  def apply_taf_policy(value)
    "-P #{value}"
  end

end
