#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'

Puppet::Type.newtype(:ora_awr_settings) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    This resource allows you to manage AWR settings in an Oracle database.


    This type allows you to set retention, interval and topnsql


        ora_awr_settings { 'DBNAME':
          retention     => 60,
          snap_interval => 8,
          topnsql       => 'DEFAULT',
        }

    This will set the default AWR settings for database 'DBNAME'

  EOD

  to_get_raw_resources do
    running_mt_database_sids.collect do |db|
      command = if local_pdb?(db)
                  %Q(select *
                       from (select extract(day from snap_interval)*24*60 + extract(hour from snap_interval)*60 + extract(minute from snap_interval) as snap_interval
                                  , extract(day from retention) as retention
                                  , topnsql
                                  , src_dbname as name
                               from cdb_hist_wr_control
                              where src_dbname = sys_context('USERENV', 'CON_NAME')))
                else
                  %Q(select *
                       from (select extract(day from snap_interval)*24*60 + extract(hour from snap_interval)*60 + extract(minute from snap_interval) as snap_interval
                                  , extract(day from retention) as retention
                                  , topnsql
                               from dba_hist_wr_control),
                            (select instance_name as name
                               from v$instance))
                end
      sql(command, :sid => db).first
    end
  end

  on_create do
    nil
  end

  on_modify do
    nil
  end

  parameter :name

  property :retention
  property :snap_interval
  property :topnsql

end
