#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:archivelog) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  newvalues(:enabled, :disabled)
  data_type("Optional[Enum['enabled', 'disabled']]")

  desc <<-EOD
    Enable or disable archive log.
  EOD

  to_translate_to_resource do |raw_resource|
    log_mode = raw_resource.column_data('LOG_MODE')
    if log_mode == 'ARCHIVELOG'
      'enabled'
    elsif log_mode == 'NOARCHIVELOG'
      'disabled'
    else
      nil
    end
  end

  on_apply do
    enabled? ? 'archivelog' : 'noarchivelog'
  end

  on_modify do
    if flashback_enabled? and flashback_should == 'disabled'
      sql("alter database flashback off", :sid => instance)
    end
    unless arch_is == should
      log_mode = enabled? ? 'archivelog' : 'noarchivelog'
      statement = template('ora_config/ora_database/archivelog.sql.erb', binding)
      sql(statement, :sid => instance)
    end
    if !flashback_enabled? and flashback_should == 'enabled'
      sql("alter database flashback on", :sid => instance)
    end
    nil
  end

  def insync?(is)
    return true if resource.contained_by
    super
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end

  def arch_is
    provider.archivelog
  end

  def flashback_enabled?
    provider.flashback == 'enabled'
  end

  def flashback_should
    resource.flashback
  end
end
