#
# See the file "LICENSE" for the full license governing this code.
#
# encoding: UTF-8
newproperty(:container_database, :parent => ::Puppet_X::EnterpriseModules::Oracle::ReadOnlyProperty) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Information

  to_translate_to_resource do |raw_resource|
    if raw_resource['STATE'] == 'running'
      containerdb?(raw_resource['SID']) ? :enabled : :disabled
    else
      nil
    end
  end

  newvalues(:enabled, :disabled)
  data_type("Optional[Enum['enabled', 'disabled']]")

  defaultto :disabled

  desc <<-EOD
    Enable or disable the containers and adding pluggable databases

    Using this parameter, you can enable this database,beeing a host for plugganle databases.

        ora_database { 'my_database':
          ensure             => present,
          ...
          container_database => 'enabled',
          ...
        }

    Will enable this database to be a host for pluggable databases. This feature needs Oracle 12 or higher. If you
    use this feature on a database before Oracle 12, SQL will throw an error.

  EOD

  on_apply do
    enabled? ? 'enable pluggable database' : ''
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end
end
