#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:flashback) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  newvalues(:enabled, :disabled)
  data_type("Optional[Enum['enabled', 'disabled']]")

  desc <<-EOD
    Enable or disable flashback database.
  EOD

  to_translate_to_resource do |raw_resource|
    flashback_mode = raw_resource.column_data('FLASHBACK_ON')
    if flashback_mode == 'YES'
      'enabled'
    elsif flashback_mode == 'NO'
      'disabled'
    else
      nil
    end
  end

  on_apply do
    enabled? ? 'on' : 'off'
  end

  on_modify do
    # on_modify is handled in on_modify of archivelog property as part of arch_group group
    nil
  end

  def insync?(is)
    return true if resource.contained_by
    super
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end
end
