#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop: disable Metrics/BlockLength
newproperty(:value, :array_matching => :all) do
  include EasyType
  include EasyType::Mungers::String
  include Puppet_X::EnterpriseModules::Oracle::Access
  #
  # Aslways convert the values to a string representation here. In the routine specified_value of the type,
  # it will be converted to the actual representation.
  #

  desc <<-EOD
    The value or values of the parameter.

    You can use either a single value or an Array value. Although not strictly required, we
    reccomend that you alsways use quoted values. Also when using nummeric or boolean values.


    An example  using a boolean value:

        ora_init_param { ....:
          ...
          value  => 'FALSE',
        }

    Here an example using an array of values:

        ora_init_param { ....:
          ...
          value  => ['RECODG', 'BACKUPDG', 'DATADG'],
        }

        ora_init_param { ...:
          ...
          value  => '1',
        }
  EOD

  # TODO: See if we can and need to make this a bit more specific
  data_type("Optional[Any]")

  #
  # Order doesn't matter
  #
  def insync?(is)
    is = [] if is.to_s == 'absent' || is.nil?
    should_value = should.size == 1 ? should.first : should
    if puppet_5_or_higher?
      Array(determine_type(is)).sort == Array(determine_type(should_value)).sort
    else
      Array(is).sort == Array(should_value).sort
    end
  end

  def change_to_s(is, should)
    should_value = should.size == 1 ? should.first : should
    "value changed #{is} to #{should_value}"
  end


  to_translate_to_resource do |raw_resource|
    value = raw_resource.column_data('DISPLAY_VALUE')
    if puppet_5_or_higher?
      value.is_a?(::Array) ? value.collect { |e| determine_type(hex_to_raw(e)) } : determine_type(hex_to_raw(value))
    else
      value.is_a?(::Array) ? value.collect { |e| hex_to_raw(e) } : hex_to_raw(value)
    end
  end

  def self.puppet_5_or_higher?
    Gem::Version.new(Puppet.version).to_s.split('.').first.to_i > 5
  end

  def puppet_5_or_higher?
    self.class.puppet_5_or_higher?
  end

  def self.determine_type(str)
    if (num = Integer(str) rescue Float(str) rescue nil)
      num
    else
      str
    end
  end

  def determine_type(str)
    self.class.determine_type(str)
  end

end
