#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

Puppet::Type.newtype(:ora_scheduler_job) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  extend Puppet_X::EnterpriseModules::Oracle::TitleParser
  include Puppet_X::EnterpriseModules::Oracle::DefaultSid

  desc <<-EOD
  This resource allows you to manage schedulaed jobs in the Oracle database. Here is
  an example on how to use this:

      ora_scheduler_job{'sys.cleanup_audit_job@SID':
        ensure          => 'present',
        job_type        => 'PLSQL_BLOCK',
        job_action      => 'begin cleanup_audit; end;',
        start_date      => '18-10-2018 23:45:00',
        repeat_interval => 'FREQ=DAILY',
        comments        => 'Purge Audit Logs',
        enabled         => 'TRUE',
      }

  EOD

  to_get_raw_resources do
    sql_on_all_primary_database_sids template('ora_config/ora_scheduler_job/index.sql.erb', binding)
  end

  on_create do
    apply
  end

  on_modify do
    nil
  end

  on_destroy do
    [:sql, "exec DBMS_SCHEDULER.DROP_JOB(job_name => '#{owner}.#{job_name}', force => TRUE)", {:sid => sid}]
  end

  def apply
    fail "#{name}: Needs job_action property" unless job_action
    options = { :sid => sid, :parse => false, :catch_extra_errors => /compilation errors/ }
    options[:failonsqlfail] = true
    job_action_content = get_content(job_action)
    statement = template('ora_config/ora_scheduler_job/create_job.sql.erb', binding)

    output = sql statement, options
    Puppet.debug(output) if logoutput.to_s == 'true'
    nil
  end

  def get_content(input)
    if Pathname(input).absolute?
      if File.file?(input)
        File.read(input)
      else
        fail "Unable to find file #{input} for job_action content"
      end
    else
      input
    end
  end

  map_title_to_sid(:owner, :job_name) { /(.+)\.(.+)/ }

  ensurable

  parameter :name
  parameter :owner
  parameter :job_name

  parameter :sid
  parameter :logoutput
  parameter :report_errors

  property  :auto_drop
  property  :comments
  property  :enabled
  property  :end_date
  property  :job_action
  property  :job_class
  property  :job_priority
  property  :job_type
  property  :logging_level
  property  :max_runs
  property  :max_failures
  property  :max_run_duration
  # property  :raise_events
  property  :repeat_interval
  property  :restartable
  # property  :restart_on_failure
  # property  :restart_on_recovery
  property  :schedule_limit
  property  :start_date
  # property  :stop_on_window_close
  # property  :store_output

  ora_autorequire(:ora_user, :owner)

end
