#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:comments) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Adds a comment to the job. 

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          comments => 'This is job my_job in schema me',
          ...
        }

    Puppet doesn't provide a default value.

  EOD

  data_type("Optional[String]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('COMMENTS')
  end

  on_modify do
    if resource.comments == '' or resource.comments.nil?
      statement = "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'COMMENTS'); end;\n/\n"
    else
      statement = template('ora_config/ora_scheduler_job/modify_quoted_attribute.sql.erb', binding)
    end
    sql statement, {:sid => resource.sid}
  end

end
