#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:enabled) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Indicates wether or not the job is enabled. 

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          enabled => 'TRUE',
          ...
        }

    Default value: 'TRUE'

  EOD

  newvalues('TRUE', 'FALSE')
  data_type("Optional[Enum['TRUE', 'FALSE']]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('ENABLED')
  end

  on_modify do
    if should.to_s.upcase == 'FALSE'
      statement = "begin dbms_scheduler.disable(name => '#{resource.owner}.#{resource.job_name}', force => true); end;\n/\n"
    else
      statement = "begin dbms_scheduler.enable(name => '#{resource.owner}.#{resource.job_name}'); end;\n/\n"
    end
    sql statement, {:sid => resource.sid}
  end

end
