#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:restartable) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Indicates wether or not the job can be restarted in case of failure. 

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          restartable => 'TRUE',
          ...
        }

    Default value: 'FALSE'

  EOD

  defaultto 'FALSE'

  newvalues('TRUE', 'FALSE')
  data_type("Optional[Enum['TRUE', 'FALSE']]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('RESTARTABLE')
  end

  on_modify do
    statement = template('ora_config/ora_scheduler_job/modify_unquoted_attribute.sql.erb', binding)
    sql statement, {:sid => resource.sid}
  end

end
