#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:schedule_limit) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies the maximum delay between the scheduled time and the actual start of the job
    before the run is skipped, specified in seconds.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          schedule_limit => '3600',
          ...
        }

    Puppet doesn't provide a default value.

  EOD

  data_type("Optional[Integer]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('SCHEDULE_LIMIT').to_i
  end

  on_modify do
    if resource.schedule_limit == '' or resource.schedule_limit.nil?
      statement = "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'SCHEDULE_LIMIT'); end;\n/\n"
    else
      statement = template('ora_config/ora_scheduler_job/modify_interval_attribute.sql.erb', binding)
    end
    sql statement, {:sid => resource.sid}
  end

end
