#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:service_name) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Mungers::Upcase
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Information

  desc <<-EOD
    The service name.

    When the Oracle init parameter `db_domain` is set, the service name
    **MUST** be a full qualified name. e.g. a name containing a domain.
    For example:

        ora_service{'mydb.mydomain.com@sid':
          ensure => 'present',
        }

    If the parameter `db_domain` is empy, you can use unqualified names.
    For example:

        ora_service{'mydb@sid':
          ensure => 'present',
        }


  EOD

  validate do |value|
    if resource.sid
      unless db_domain.empty?
        fail "init parameter db_domain is set to #{domain}. Therfore service name must be a full qualified name, including a domain name" unless value.include?('.')
      end
    end
  end

  isnamevar

  data_type("String[1]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('NAME').upcase
  end

  def db_domain
    begin
      #
      # When there is no database, this fails. So when there is no database
      # we don't do this check
      #
      domain = db_domain(resource.sid)
    rescue
      domain = ''
    end
    domain
  end
end
