#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:session_state) do
  include Puppet_X::EnterpriseModules::Oracle::Mungers::Upcase
  include Puppet_X::EnterpriseModules::Oracle::ServiceProperty

  desc <<-EOD
    For Application Continuity, this parameter specifies whether the session state that is not transactional
    is changed by the application. Oracle recommends a setting of DYNAMIC for most applications.
    This parameter is considered only if `failover_type` is set to TRANSACTION for Application Continuity.

    Here is an example on how to use this:

        ora_service{'my_service':
          ...
          session_state => 'DYNAMIC',
          ...
        }

    Puppet provides no default value. But Oracle might, depending on your version.

    This is a cluster only property. On single node database this property will be ignored. If you use it,
    Puppet will issue a warning.

  EOD

  column_name 'Session State Consistency'
  newvalues(:DYNAMIC, :STATIC, :dynamic, :static)
  data_type("Optional[Enum['DYNAMIC', 'STATIC', 'dynamic', 'static']]")
end
