#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:logging) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specify the default logging attributes of all tables, indexes, materialized views, materialized view logs, and partitions within the tablespace.
  EOD

  newvalues('yes', 'no')
  data_type("Optional[Enum['yes', 'no']]")

  to_translate_to_resource do |raw_resource|
    return nil unless raw_resource['CONTENTS'] == 'PERMANENT'
    case raw_resource.column_data('LOGGING')
    when 'LOGGING' then 'yes'
    when 'NOLOGGING' then 'no'
    else
      fail('Invalid Logging found in tablespace resource.')
    end
  end

  after_modify do
    logging = resource[:logging].to_s == 'yes' ? 'logging' : 'nologging'
    sql("alter tablespace #{resource[:tablespace_name]} #{logging}", :sid => resource.sid)
  end

  on_create do
    if resource[:logging].to_s == 'yes'
      'logging'
    else
      'nologging'
    end
  end
end
