#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:password) do
  include EasyType
  include EasyType::EncryptedProperty
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Password
  include Puppet_X::EnterpriseModules::Oracle::CreateOnly


  desc <<-EOD
    The user's password.
  EOD

  data_type('Optional[String[1]]')

  #
  # Needed for information
  #
  def sid
    resource.sid
  end

  on_modify do
    "identified by \"#{value}\""
  end

  after_modify do
    if oracle_major_version(sid_from_resource) > 12 && resource.username.upcase == 'SYS'
      #
      # The regular password update statement, doesn't update the the spare4 field on these
      # oracle versions when updateing the SYS password. SO we set it ourselfs to make
      # sure it is idempotent. If the user is not SYS, leave everything to Oracle.
      #
      sql("UPDATE sys.user$ set spare4='#{password_for_update}' WHERE name='SYS'",:sid => resource.sid)
    end
  end

  def insync?(_is)
    return false if is_password_hash.nil?
    create_only_insync?(is_password_hash, should_password_hash)
  end

end
