#!/opt/puppetlabs/puppet/bin/ruby
#
# See the file "LICENSE" for the full license governing this code.
#
require 'json'
require 'puppet'

begin
  Puppet.initialize_settings
rescue Puppet::DevError
  # When run in Rspec, this is called multiple times
end

begin
  params      = JSON.parse(STDIN.read)
  sid         = params.fetch('sid')
  oracle_home = params.fetch('oracle_home')
  os_user     = params.fetch('os_user')
  directory   = params.fetch('directory')

  environment = {}
  environment[:ORACLE_HOME] = oracle_home
  environment[:ORACLE_SID] = sid
  environment[:PATH] = "/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:#{oracle_home}/bin"
  commands = [
    "backup database format '#{directory}/%d_%T_%u.bkp' plus archivelog format '#{directory}/%d_%T_%u.bkp';",
    "backup current controlfile format '#{directory}/%d_%T_%u.bkp' spfile format '#{directory}/%d_%T_%u.bkp';"
  ]
  backup_commands = commands.join("\n")
  command = "echo \"#{backup_commands}\" | #{oracle_home}/bin/rman target /"
  result = Puppet::Util::Execution.execute(command, :failonfail => true, :custom_environment => environment, :uid => os_user)
  dbid = result.scan(/DBID=(.*)\)/).flatten.first
  sql_command = "echo \"set heading off\nselect value from gv\\$parameter where name = 'compatible';\" | #{oracle_home}/bin/sqlplus -s / as sysdba"
  compatible_result = Puppet::Util::Execution.execute(sql_command, :failonfail => true, :custom_environment => environment, :uid => os_user)
  File.open("#{directory}/dbid.txt", "w") { |f| f.write dbid }
  File.open("#{directory}/compatible.txt", "w") { |f| f.write compatible_result.delete("\n") }
  File.open("#{directory}/source_db.txt", "w") { |f| f.write sid }
  FileUtils.chown os_user, -1, [ "#{directory}/source_db.txt", "#{directory}/compatible.txt", "#{directory}/dbid.txt" ]
  puts({ :step => 'full backup', :status => 'success', :output => result }.to_json)

rescue Puppet::Error => e
  puts({ :status => 'failure', :error => e.message }.to_json)
  exit 1
end
