#!/opt/puppetlabs/puppet/bin/ruby
#
# See the file "LICENSE" for the full license governing this code.
#
require 'json'
require 'puppet'

begin
  Puppet.initialize_settings
rescue Puppet::DevError
  # When run in Rspec, this is called multiple times
end

begin
  # TODO: export pluggable database
  params = JSON.parse(STDIN.read)
  sid                    = params.fetch('sid')
  oracle_home            = params.fetch('oracle_home')
  cdb                    = params.fetch('cdb')
  pluggable              = params.fetch('pluggable')
  contained_by           = params.fetch('contained_by')
  database_user          = params.fetch('database_user') { "" }
  database_user_password = params.fetch('database_user_password') { "" }
  os_user                = params.fetch('os_user')
  directory              = params.fetch('directory')
  schemas                = params.fetch('schemas')
  $LOAD_PATH << "#{params['_installdir']}/easy_type/lib"
  $LOAD_PATH << "#{params['_installdir']}/ora_config/lib"
  require 'easy_type'
  require 'puppet_x/enterprisemodules/oracle/access'
  include Puppet_X::EnterpriseModules::Oracle::Access

  # Create directory in database:
  directory_name = 'EXTRACT_DATA_DP'
  result = sql("create or replace directory #{directory_name} as '#{directory}'", {:sid => sid})
  puts({ :step => 'create directory', :status => 'success', :output => result }.to_json)

  # Export database
  if database_user.length > 0
    connect_string = "#{database_user}/#{database_user_password}"
  else
    connect_string = '/ as sysdba'
  end
  dumpfile = "#{directory_name}_#{sid}.dmp"
  logfile = "expdp_#{directory_name}_#{sid}.log"
  if schemas.length > 0
    content = "schemas=#{schemas.join(',')}"
  else
    content = "full=yes"
  end
  environment = {}
  environment[:ORACLE_HOME] = oracle_home
  environment[:ORACLE_SID] = sid
  environment[:PATH] = "/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:#{oracle_home}/bin"
  command = "echo #{connect_string} | #{oracle_home}/bin/expdp directory=#{directory_name} dumpfile=#{dumpfile} logfile=#{logfile} reuse_dumpfiles=yes #{content}"
  result = Puppet::Util::Execution.execute(command, :failonfail => true, :custom_environment => environment, :uid => os_user)
  puts({ :step => 'export', :status => 'success', :output => result }.to_json)

  # Remove the directory
  result = sql("drop directory #{directory_name}", {:sid => sid})
  puts({ :step => 'remove directory', :status => 'success', :output => result }.to_json)
rescue Puppet::Error => e
  puts({ :status => 'failure', :error => e.message }.to_json)
  exit 1
end
